function [EEin,EEout,EEmould,EEspray] = ... 
     glbene(U,fliq,xnod,node_in,node_out,nnodx, ...
     node_mould,node_spray,qs,laxis,Carbon,gradT)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%                        " GLOENE "
%
%     [Ein,Eout,EEmould,EEspray] = ... 
%           glbene(U,fliq,xnod,node_in,node_out,nnodx,
%            node_mould,node_spray,qs,laxis,Carbon,gradT)
%
%         BALANCE GLOBAL DE ENERGIA PARA LA COLADA CONTINUA
%
%      CASO AXISIMETRICO
%
%      U          -------->   vector solucion
%      fliq       -------->   fraccion de liquido
%      xnod       -------->   vector coordenadas
%      node_in    -------->   nodos en la tobera de entrada
%      node_out   -------->   nodos a la salida
%      nnodx      -------->   numero de nodos en la direccion "X"
%      node_mould -------->   nodos sobre el molde
%      node_spray -------->   nodos en el spray
%      qs         -------->   flujo de calor extraido por el molde
%      laxis      -------->   axisimetrico (~0) o plano(0)
%      gradT      -------->   (1) usa el modelo con grad T en la entrada 
%                             salida. (0) si no lo usa
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if laxis,
   disp('    BALANCE GLOBAL DE ENERGIA   -   AXISIMETRICO ')
else
   disp('    BALANCE GLOBAL DE ENERGIA   -   PLANO ')
end


% Propiedades del material
%-----------------------------------------------

if Carbon == 0.1,

% Acero Fe-C con 0.1 %
%-----------------------------------------------
rho = 7020;
Cp  = 680;
Tsol= 1490;
Tliq= 1530;
Lat_heat = 272000;
kappa_l  = 34;
kappa_s  = 34;
h_spray  = 1080;
h_mould  = 1270;
T_amb    = 40;
R_mould  = 0.0575;
R_nozzle = 0.015;
Carbon   = 0.1;

elseif Carbon==0.8,

% Acero Fe-C con 0.8 %
%-----------------------------------------------
rho = 7020;
Cp  = 680;
Tsol= 1375;
Tliq= 1475;
Lat_heat = 272000;
kappa_l  = 34;
kappa_s  = 34;
h_spray  = 1080;
h_mould  = 1270;
T_amb    = 40;
R_mould  = 0.0575;
R_nozzle = 0.015;
Carbon   = 0.8;

elseif Carbon==0.4,

% Acero Fe-C con 0.4 %
%-----------------------------------------------
rho = 7020;
Cp  = 680;
Tm  = 1534;
slopel = -80.3920;
kp    = 0.1961;
Tsol= Tm+slopel/kp*Carbon;
Tliq= Tm+slopel*Carbon;
Lat_heat = 272000;
kappa_l  = 34;
kappa_s  = 34;
%h_spray  = [433*ones(19,1);300*ones(19,1);167*ones(20,1)];
h_spray  = [500*ones(19,1);500*ones(19,1);500*ones(20,1)];
%h_mould  = 770*ones(length(node_mould),1);
h_mould  = 0*ones(length(node_mould),1);
T_amb    = 60;
R_mould  = 0.1048;
R_nozzle = 0.020;
Carbon   = 0.4;

else

  error(' Carbon content does not match with our data ')

end

Hin = zeros(length(node_in),1);
Hout = zeros(length(node_out),1);


% layer de nodos offset de la entrada y salida 
% para calcular el gradiente de temperatura
%------------------------------------------------
if gradT ==1,
  node_in_of   = node_in  + nnodx ;
  node_out_of  = node_out - nnodx ;
end

xin = xnod(node_in,1);
Tin = U(node_in,4);
Uin = U(node_in,2);
flin= fliq(node_in);

Hin = (flin.*Lat_heat + Cp * Tin)*rho .* Uin ;
Cin = rho .* Uin .* U(node_in,5);

xout = xnod(node_out,1);
Tout = U(node_out,4);
Uout = U(node_out,2);
flout= fliq(node_out);

Hout = (flout.*Lat_heat + Cp * Tout)*rho .* Uout ;
Cout = rho .* Uout .* U(node_out,5);

Ein  = Hin ;
Eout = Hout;

if gradT ==1,
Tin_of    = U(node_in_of,4);
dx_in     = (xnod(node_in_of,2)-xnod(node_in,2));
dT_in     = Tin_of-Tin;

Tout_of   = U(node_out_of,4);
dx_out    = (xnod(node_out_of,2)-xnod(node_out,2));
dT_out    = Tout_of-Tout;

gradT_in  = dT_in ./ dx_in ; 
gradT_out = dT_out ./ dx_out ; 

kappa_in  = kappa_s*(1-flin )+flin *kappa_l;
kappa_out = kappa_s*(1-flout)+flout*kappa_l;

Ein       =  Ein  - kappa_in  .* gradT_in ; 
Eout      =  Eout - kappa_out .* gradT_out ; 

end

if laxis,
  EEin      = trapz(xin,Ein.*(2*pi*xin));
  CCin      = trapz(xin,Cin.*(2*pi*xin));
else
  EEin      = trapz(xin,Ein);
  CCin      = trapz(xin,Cin);
end

if laxis,
  EEout      = trapz(xout,Eout.*(2*pi*xout));
  CCout      = trapz(xout,Cout.*(2*pi*xout));
else
  EEout      = trapz(xout,Eout);
  CCout      = trapz(xout,Cout);
end

% Flujo de calor extraido por el molde y los sprays
%------------------------------------------------------------

xmould = xnod(node_mould,2);
T_mould   = U(node_mould,4);

if laxis,
  EEmould  = 2*pi*R_mould*trapz(xmould,qs) + ...
             2*pi*R_mould*trapz(xmould,-h_mould.*(T_mould-T_amb));
else
  EEmould  = trapz(xmould,qs) + ...
             trapz(xmould,-h_mould.*(T_mould-T_amb));
end


R_spray     = R_mould;
xspray      = xnod(node_spray,2);
T_spray   = U(node_spray,4);


if laxis,
  EEspray = 2*pi*R_spray*trapz(xspray,-h_spray.*(T_spray-T_amb));
else
  EEspray = trapz(xspray,-h_spray.*(T_spray-T_amb));
end


disp('-----------------------------------------------------')
disp('   PROPIEDADES DEL MATERIAL Y DATOS GEOMETRICOS USADOS ')
disp('-----------------------------------------------------')
disp([' Acero al carbono con ' num2str(Carbon) ' % de C ']) 
disp([' Densidad          ------->   ' num2str(rho) ])
disp([' Calor especifico  ------->   ' num2str(Cp) ])
disp([' Calor latente     ------->   ' num2str(Lat_heat) ])
disp([' Temperatura liq   ------->   ' num2str(Tliq) ])
disp([' Temperatura sol   ------->   ' num2str(Tsol) ])
disp([' Cond. term. liq   ------->   ' num2str(kappa_l) ])
disp([' Cond. term. sol   ------->   ' num2str(kappa_s) ])
%disp([' coef conv molde   ------->   ' num2str(h_mould) ])
%for k=1:length(h_spray),
%disp([' coef conv spray   ------->   ' num2str(h_spray(k)) ])
%end
disp([' Temperatura amb   ------->   ' num2str(T_amb) ])
disp([' R_molde           ------->   ' num2str(R_mould) ])
disp([' R_tobera entrada  ------->   ' num2str(R_nozzle) ])
disp('-----------------------------------------------------')


disp('-----------------------------------------------------')
disp([' Energia entrada  ------->   ' num2str(EEin)])
disp([' Energia salida   ------->   ' num2str(EEout)])
disp([' Calor ext molde  ------->   ' num2str(abs(EEmould))])
disp([' Calor ext spray  ------->   ' num2str(abs(EEspray))])
disp('-----------------------------------------------------')

EEtot = EEin - EEout + EEmould + EEspray ;

disp('-----------------------------------------------------')
disp([' Difer abs   ------->   ' num2str(EEtot) ... 
      ' Difer rel (%)------>   ' num2str(EEtot/EEin*100) ])
disp('-----------------------------------------------------')
disp('-----------------------------------------------------')
disp([' Carbon in  ---------------------> '  num2str(CCin)  ])
disp([' Carbon out ---------------------> '  num2str(CCout) ])
disp('-----------------------------------------------------')