function [r] = r_valve(U)
%
%    Residual computation on valve model
%

global datos_valve datos_gral

tol      = 1e-16;
nvalves  = length(datos_valve);
dt       = datos_gral.dt;

%if nvalves > 1, error(' Check r_valve.m routine for nvalves > 1 '); end 

U_cylinder = U(3*nvalves+(1:nvalves),:);  % cylinder state
U_valve_th = U(2*nvalves+(1:nvalves),:);  % valve throat state
U_pipe_end = U(1*nvalves+(1:nvalves),:);  % end pipe state
U_pipe_int = U(          (1:nvalves),:);  % interior pipe state

x_P      = zeros(nvalves,1);

get_phys_prop;
delta = (ga-1)/2;

r = zeros(nvalves,6);

for k=1:nvalves
    
    type_end = datos_valve(k).type_end;
    dx       = datos_valve(k).dx; 
    Area_P   = datos_valve(k).Area_pipe;
    Area_G   = datos_valve(k).Area_throat;
    
    [U_S,U_R,indx_tubes_out,x_S,x_R] = ... 
        valve_model_get_state(U_pipe_int(k,:),U_pipe_end(k,:),U_cylinder(k,:),dx,dt,x_P(k),type_end);
    
    [rho_G,u_G,p_G] = unpack(U_valve_th(k,:));
    [rho_P,u_P,p_P] = unpack(U_pipe_end(k,:));
    [rho_C,p_C,Temp_C] = unpack(U_cylinder(k,:));
    [rho_S,u_S,p_S] = unpack(U_S);
    
    type_end_flow = sign(type_end.*u_P);
    
    if (type_end_flow<0)
        [rho_R,u_R,p_R] = unpack(U_R); 
        [RHS1,RHS2m,RHS2p] = rhs1y2(U_R,U_S,U_S,dt,datos_valve(k));    
    else
        [RHS1,RHS2m,RHS2p] = rhs1y2(U_S,U_S,U_S,dt,datos_valve(k));    
    end
    
    
    if (type_end_flow>0)
        % from cylinder to pipe through valve (IMBOCCO)
        % eq compatibility along Mach lines (lambda minus)    
        a_S  = sqrt(ga*p_S./rho_S);
        if(u_P>0)
            r(k,1) = (p_P-p_S)./(rho_S.*a_S)+u_S+RHS2m-u_P;
        else
            r(k,1) = (p_P-p_S)./(rho_S.*a_S)+u_P+RHS2p-u_S;        
        end    
        
        % eq continuity throat-pipe
        psi = Area_G./Area_P;
        r(k,2) = rho_G.*u_G.*psi-rho_P.*u_P;
        
        % eq energy cylinder to pipe
        a_C  = sqrt(ga*p_C./rho_C);
        a_G  = sqrt(ga*p_G./rho_G);
        a_P  = sqrt(ga*p_P./rho_P);
        r(k,3) = a_C.^2-(a_P.^2+delta*u_P.^2);
        
        % eq isoentropic cylinder to throat
        r(k,4) = p_C./p_G-(rho_C./rho_G).^ga;
        
        % eq energy cylinder throat
        r(k,5) = a_C.^2-(a_G.^2+delta*u_G.^2);
        
        % eq isobaric throat-cylinder
        sigma=0.025*a_G;
        fi = 0.5*(1+tanh((a_G-u_G)/sigma));
        r_sonic = a_G-u_G;
        r_subsonic = p_G-p_P;
        r(k,6) = (1-fi).*r_sonic+fi.*r_subsonic;        
        
    else
        % from pipe to cylinder through valve (SBOCCO)
        % eq compatibility along Mach lines (lambda minus)    
        a_S  = sqrt(ga*p_S./rho_S);
        if(u_P>0)
            r(k,1) = (p_P-p_S)./(rho_S.*a_S)+u_P+RHS2p-u_S;
        else
            r(k,1) = (p_P-p_S)./(rho_S.*a_S)+u_S+RHS2m-u_P;
        end
        
        % eq continuity throat-pipe
        psi = Area_G./Area_P;
        r(k,2) = rho_G.*u_G.*psi-rho_P.*u_P;
        
        % eq compatibility along path line (u)
        r(k,3) = (p_P./p_R).^(1/ga)-(rho_P./rho_R).*exp(RHS1);
        
        % eq isoentropic pipe-throat
        r(k,4) = p_P./p_G-(rho_P./rho_G).^ga;
        
        % eq energy pipe-throat
        a_G  = sqrt(ga.*p_G./rho_G);
        a_P  = sqrt(ga.*p_P./rho_P);
        
        % eq energy pipe throat
        r(k,5) = a_P.^2+delta*u_P.^2-(a_G.^2+delta*u_G.^2);
        
        % eq isobaric throat-cylinder
        sigma=0.025*a_G;
        fi = 0.5*(1+tanh((a_G-u_G)/sigma));
        r_sonic    = a_G-u_G;
        r_subsonic = p_G-p_C;
        r(k,6) = (1-fi).*r_sonic+fi.*r_subsonic;
        
    end
end

%disp('r_valve');keyboard;pause
r = reshape(r',6*nvalves,1);

return

